@@ -84,7 +84,7 @@ class MetadataXml:
 
     __slots__ = (
         "__weakref__", "_maintainers", "_local_use",
-        "_longdescription", "_source",
+        "_longdescription", "_source", "_stabilize_allarches",
     )
 
     def __init__(self, source):
@@ -95,7 +95,8 @@ class MetadataXml:
             self._parse_xml()
         return getattr(self, attr)
 
-    for attr in ("maintainers", "local_use", "longdescription"):
+    for attr in ("maintainers", "local_use", "longdescription",
+                 "stabilize_allarches"):
         locals()[attr] = property(post_curry(_generic_attr, "_" + attr))
     del attr
 
@@ -109,6 +110,7 @@ class MetadataXml:
             self._local_use = mappings.ImmutableDict()
             self._longdescription = None
             self._source = None
+            self._stabilize_allarches = False
             logger.error(e)
             return
 
@@ -123,9 +125,13 @@ class MetadataXml:
                     email = e.text
                 elif e.tag == 'description' and e.get('lang', 'en') == 'en':
                     description = e.text
-            maintainers.append(Maintainer(
-                name=name, email=email, description=description,
-                maint_type=x.get('type')))
+            try:
+                maintainers.append(Maintainer(
+                    name=name, email=email, description=description,
+                    maint_type=x.get('type')))
+            except ValueError:
+                # ignore invalid maintainers that should be caught by pkgcheck
+                pass
 
         self._maintainers = tuple(maintainers)
 
@@ -153,6 +159,8 @@ class MetadataXml:
             )
             break
 
+        self._stabilize_allarches = tree.find("stabilize-allarches") is not None
+
 
 class LocalMetadataXml(MetadataXml):
 
@@ -166,6 +174,7 @@ class LocalMetadataXml(MetadataXml):
             self._local_use = mappings.ImmutableDict()
             self._longdescription = None
             self._source = None
+            self._stabilize_allarches = False
 
 
 class SharedPkgData:
@@ -177,7 +186,7 @@ class SharedPkgData:
         self.manifest = manifest
 
 
-class ProjectMember(object, metaclass=klass.generic_equality):
+class ProjectMember(metaclass=klass.generic_equality):
     """Data on a single project member.
 
     :type email: C{unicode} object
@@ -386,7 +395,7 @@ class LocalProjectsXml(ProjectsXml):
             return mappings.ImmutableDict()
 
 
-class Licenses(object, metaclass=WeakInstMeta):
+class Licenses(metaclass=WeakInstMeta):
 
     __inst_caching__ = True
 
