@@ -14,7 +14,8 @@ class TestMetadataXml:
 
     @staticmethod
     def get_metadata_xml(maintainers=(), comments=(), local_use={},
-                         longdescription=None, maint_type=None):
+                         longdescription=None, maint_type=None,
+                         stabilize_allarches=False):
         cs = '\n'.join(comments)
         ms = us = ls = ""
         if maintainers:
@@ -37,11 +38,12 @@ class TestMetadataXml:
             us = '\n'.join(us)
         if longdescription:
             ls = f"<longdescription>{longdescription}</longdescription>\n"
+        sa = "<stabilize-allarches/>" if stabilize_allarches else ""
         s = \
 f"""<?xml version="1.0" encoding="UTF-8"?>
 <!DOCTYPE pkgmetadata SYSTEM "http://www.gentoo.org/dtd/metadata.dtd">
 <pkgmetadata>
-{cs}{ms}{us}{ls}</pkgmetadata>"""
+{cs}{ms}{us}{ls}{sa}</pkgmetadata>"""
         return repo_objs.MetadataXml(data_source(s.encode('utf-8')))
 
     def test_empty_maintainers(self):
@@ -119,6 +121,12 @@ Blake-light tragedy among the scholars of war.
 
         assert " ".join(s.split()) == self.get_metadata_xml(longdescription=s).longdescription
 
+    def test_stabilize_allarches(self):
+        # missing
+        assert False == self.get_metadata_xml().stabilize_allarches
+        # present
+        assert True == self.get_metadata_xml(stabilize_allarches=True).stabilize_allarches
+
 
 class TestProjectsXml:
 
